
import { localize } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { ExecutionEngine } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/tasks/common/tasks';
import { AbstractTaskService } from './abstractTaskService.js';
import '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation';
import '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/extensions';

class TaskService extends AbstractTaskService {
    static { this.ProcessTaskSystemSupportMessage = ( localize(9130, 'Process task system is not support in the web.')); }
    _getTaskSystem() {
        if (this._taskSystem) {
            return this._taskSystem;
        }
        if (this.executionEngine !== ExecutionEngine.Terminal) {
            throw ( new Error(TaskService.ProcessTaskSystemSupportMessage));
        }
        this._taskSystem = this._createTerminalTaskSystem();
        this._taskSystemListeners =
            [
                this._taskSystem.onDidStateChange((event) => {
                    this._taskRunningState.set(this._taskSystem.isActiveSync());
                    this._onDidStateChange.fire(event);
                }),
            ];
        return this._taskSystem;
    }
    _computeLegacyConfiguration(workspaceFolder) {
        throw ( new Error(TaskService.ProcessTaskSystemSupportMessage));
    }
    _versionAndEngineCompatible(filter) {
        return this.executionEngine === ExecutionEngine.Terminal;
    }
}

export { TaskService };
